<template>
  <section
    v-if="Object.keys(mediaCenter).length"
    class="media-center"
    :class="{
    [`layout${mediaCenter.shop_style}`]: true,
    [`color${mediaCenter.shop_color}`]: true
  }">
    <header class="nav-header">
      <nav>
        <div>
          <router-link
            :to="{name: 'mediacentermain'}"
            :class="{selected: (this.$route.name === 'mediacentermain')}">HOME
          </router-link>
          <router-link
            :to="{name: 'mediacenteraccounting'}"
            :class="{selected: (this.$route.name === 'mediacenteraccounting')}">ACCOUNTING
          </router-link>
        </div>
        <div>
          <div class="network-logo">
            <img
              :src="logo"
              width="98"
              height="81">
          </div>
        </div>
      </nav>
      <div class="shop-info">
        <h1>{{ mediaCenter.name }}</h1>
        <h2>{{ mediaCenter.description }}</h2>
      </div>
    </header>
    <div class="shop-background" />
    <main class="shop-content">
      <div
        class="main-content"
        :class="{'reverse': mediaCenter.shop_color === 2 }">
        <aside class="sidebar-container">
          <div class="sidebar-header"/>
          <action-buttons
            class="action-buttons"
            v-if="Object.keys(mediaCenter).length"
            :has-swiper="hasSwiper"
            :shop="mediaCenter" />
        </aside>
        <section class="content-container">
          <div class="content-header">
            <h2>{{ contentTitle }}</h2>
          </div>
          <router-view
            :shop="mediaCenter"
            @simple-one="simpleOne"
            @simple-two="simpleTwo"
            @busy-one="busyOne"
            @busy-two="busyTwo"/>
        </section>
      </div>
    </main>
  </section>
</template>

<script>
import ActionButtons from "../ActionButtons.vue";
export default {
  components: {
    ActionButtons
  },
  computed: {
    contentTitle: function () {
      if (this.$route.name === 'mediacentermain') {
        return "Media Center Facts"
      }
      if (this.$route.name === 'mediacenteraccounting') {
        return "Accounting"
      }
      if (this.$route.name === 'mediacenteredit') {
        return "Shop Edit"
      }
    }
  },
  data() {
    return {
      mediaCenter: {},
      hasSwiper: app.computerSettings.swiper,
      logo: app.network.data.shop_logo,
    }
  },
  created: function () {
    this.getData();
  },
  mounted: function () {
    console.log('mounted');
  },
  beforeMount: function () {
    this.$router.push({name: "mediacentermain"});
  },
  methods: {
    getData: function () {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/mediacenter/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.mediaCenter = Response;
            app.Message( "Successfully loaded the Media Center!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne: function () {
      this.mediaCenter.shop_style = 1;
      this.mediaCenter.shop_color = 1;
    },
    simpleTwo: function () {
      this.mediaCenter.shop_style = 1;
      this.mediaCenter.shop_color = 2;
    },
    busyOne: function () {
      this.mediaCenter.shop_style = 2;
      this.mediaCenter.shop_color = 1;
    },
    busyTwo: function () {
      this.mediaCenter.shop_style = 2;
      this.mediaCenter.shop_color = 2;
    },
  },

}
</script>

<style lang="less">
  body {
    min-height: 120vh !important;
    background: rgb(173,171,171);
    background: linear-gradient(180deg, rgba(173,171,171,1) 0%, rgba(0,0,0,1) 100%);
    background-repeat: no-repeat;
    background-attachment: fixed;
  }
  nav {
    padding: 0 5%;
  }
  .shop-info {
    text-align: center;
    display: flex;
    flex-direction: column;
    justify-content: center;
    h1 {
      font-size: 69px;
      margin-bottom: 10px;
    }
    h2 {
      font-size: 30px;
      font-weight: 200;
    }
  }
  .main-content {
    display: flex;
  }
  .reverse {
    flex-direction: row-reverse;
  }
  @import '../../shared.less';
</style>

<style lang="less">
  .media-center.layout1.color1 {
    @bgimage: url(/images/shop/mediacenter/layout1-color1.jpg);
    @primarycolor: #0098c1;
    @secondarycolor: #f8e767;
    @tertiarycolor: #00789a;;
    @sidebarheadercolor: #CABE5D;
    @import './less/layout1.less';
  }
</style>

<style lang="less">
  .media-center.layout1.color2 {
    @bgimage: url(/images/shop/mediacenter/layout1-color2.jpg);
    @primarycolor: #5a2328;
    @secondarycolor: #acefcf;
    @tertiarycolor: #5a2328;
    @sidebarheadercolor: #799A8A;
    @import './less/layout1.less';
  }
</style>

<style lang="less">
  .media-center.layout2.color1 {
    @bgimage: url(/images/shop/mediacenter/layout2-color1.jpg);
    @primarycolor: #ef7c43;
    @secondarycolor: #333333;
    @tertiarycolor: #fff;
    @sidebarheadercolor: #718337;
    @contentheadercolor: #859d3b;
    @import './less/layout2.less';
  }
</style>

<style lang="less">
  .media-center.layout2.color2 {
    @bgimage: url(/images/shop/mediacenter/layout2-color2.jpg);
    @primarycolor: #35bbd6;
    @secondarycolor: #333333;
    @tertiarycolor: #fff;
    @sidebarheadercolor: #35bbd6;
    @contentheadercolor: #327bc8;
    @import './less/layout2.less';
  }
</style>
